View source: R/client_sendeR.R
is.client_sendeR tests if a provided object is of
the client_sendeR class and whether it has all the fields
a client_sendeR should have.
All other functions check if the provided object extends
client_sendeR (passes is.client_sendeR test) and whether it
has all the fields a given client should have.
1 2 3 4 5 6 7 |
x |
an object to be tested. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.